# scan all the files in the current directory and build a ctags-type
# file containing all the labels

# 1. The tags file is a list of lines, each line in the format:
#
#         {tagname}<Tab>{tagfile}<Tab>{tagaddress}
#
#    {tagname}    Any identifier, not containing white space..
#    <Tab>        Exactly one TAB character (although many versions of Vi can
#                 handle any amount of white space).
#    {tagfile}    The name of the file where {tagname} is defined, relative to
#                 the current directory (or location of the tags file?).
#    {tagaddress} Any Ex command.  When executed, it behaves like 'magic' was
#                 not set.

import glob
import re

tags = []

for fln in (glob.glob("*")):
    if re.match("^[A-Z0-9]+$", fln):
        print("scanning '%s'" % fln)
        with open(fln) as fp:
            for line in fp:
                line = line.rstrip("\n")
                #print(line)
                m = re.match("^([A-Z0-9&$#]+)\t", line)
                if m:
                    tagname = m.group(1)
                    tagfile = fln
                    tagaddr = "/^%s$/" % line
                    print("    found tag '%s'" % tagname)
                    tags.append( tagname + "\t" + tagfile + "\t" + tagaddr )

# the tags file must be sorted on tagname
tags.sort()
            
fh = open("tags", "w")
for line in tags:
    fh.write(line + "\n")
fh.close()
